@@ -50,8 +50,6 @@ private Q_SLOTS:
 
             fw = findFileWidget();
             QVERIFY(fw);
-            // real show() is delayed to next event.
-            QVERIFY(QTest::qWaitForWindowExposed(fw->window()));
             QCOMPARE(fw->isVisible(), true);
             fw->slotCancel();
         }
@@ -69,8 +67,6 @@ private Q_SLOTS:
 
             fw = findFileWidget();
             QVERIFY(fw);
-            // real show() is delayed to next event.
-            QVERIFY(QTest::qWaitForWindowExposed(fw->window()));
             QCOMPARE(fw->isVisible(), true);
             fw->slotCancel();
         }
