@@ -23,7 +23,6 @@
 
 #include <QDialog>
 #include <QUrl>
-#include <QTimer>
 
 class QDialogButtonBox;
 class KDEPlatformFileDialogBase : public QDialog
@@ -43,9 +42,6 @@ public:
     virtual QString currentFilterText() = 0;
     virtual QList<QUrl> selectedFiles() = 0;
 
-    void delayedShow();
-    void discardDelayedShow();
-
 Q_SIGNALS:
     void closed();
     void fileSelected(const QUrl &file);
@@ -57,7 +53,6 @@ Q_SIGNALS:
 protected:
     void closeEvent(QCloseEvent *e) override;
     QDialogButtonBox *m_buttons;
-    QTimer m_timer;
 };
 
 #endif
