@@ -37,12 +37,12 @@ public:
     /**
      * Creates a new file tree view.
      */
-    KFileTreeView(QWidget *parent = 0);
+    explicit KFileTreeView(QWidget *parent = nullptr);
 
     /**
      * Destroys the file tree view.
      */
-    ~KFileTreeView();
+    ~KFileTreeView() override;
 
     /**
      * Returns the current url.
